@@ -3,15 +3,11 @@ import zipfile
 import os
 import cv2
 import numpy as np
-from tqdm import tqdm
-import time
 
-class torgb:
+class s22rgb:
     def __init__(self, InputFilePath, OutputFilePath):
         self.InputFilePath = InputFilePath
         self.OutputFilePath = OutputFilePath
-        if os.path.exists(self.OutputFilePath) == 0:
-            os.mkdir(self.OutputFilePath)
         self.zip = self.find_zip_image_file
         self.run()
     def run(self):
@@ -20,33 +16,17 @@ class torgb:
         The batch operation
         '''
         if len(self.zip()) != 0:
-
-
-
             for i in range(len(self.zip())):
-                try:
-                    with tqdm(total=100, iterable='iterable', desc=os.path.splitext(self.zip()[i])[0]) as pbar:
-                        self.un_zip(self.zip()[i])
-                        SAFE_PATH = os.path.splitext(self.zip()[i])[0] + '.SAFE'
-                        file_dir = os.path.join( self.OutputFilePath, SAFE_PATH)
-                        imgfile, xml = self.get_file_name(file_dir)
-                        # judge L1C or L2A
-                        if os.path.basename(file_dir).split('_')[1] =="MSIL1C":
-                            band =  [1,2,3]
-                        elif os.path.basename(file_dir).split('_')[1] =="MSIL2A":
-                            band = [0, 1, 2]
-                        blue = self.read_jp2(imgfile[band[0]])
-                        green = self.read_jp2(imgfile[band[1]])
-                        red = self.read_jp2(imgfile[band[2]])
-                        jpgfile = os.path.splitext(self.zip()[i])[0] + '.jpg'
-                        tarpath = os.path.join(self.OutputFilePath, jpgfile)
-                        self.rgb_jpg(red, green, blue, tarpath)
-                        time.sleep(1)
-                        pbar.update(100)
-                except KeyboardInterrupt:
-                    pbar.close()
-                    raise
-                pbar.close()
+                self.un_zip(self.zip()[i])
+                SAFE_PATH = os.path.splitext(self.zip()[i])[0] + '.SAFE'
+                file_dir = os.path.join( self.OutputFilePath, SAFE_PATH)
+                imgfile, xml = self.get_file_name(file_dir)
+                blue = self.read_jp2(imgfile[0])
+                green = self.read_jp2(imgfile[1])
+                red = self.read_jp2(imgfile[2])
+                jpgfile = os.path.splitext(self.zip()[i])[0] + '.jpg'
+                tarpath = os.path.join( self.OutputFilePath, jpgfile)
+                self.rgb_jpg(red, green,blue , tarpath)
 
     def read_jp2(self,file):
         """
@@ -129,7 +109,6 @@ class torgb:
         maxout = 255
         minout = 0
 
-
         data_8bit_new = minout + ((band_data - d2) / (u98 - d2)) * (maxout - minout)
         data_8bit_new[data_8bit_new < minout] = minout
         data_8bit_new[data_8bit_new > maxout] = maxout
@@ -152,8 +131,6 @@ class torgb:
 
 
 if __name__ == '__main__':
-
-    img = 'D:\\'
-    img = r'C:\Users\ytkz1\Downloads'
-    out = 'D:\\sentinel'
-    torgb(img, out)
+    img = 'G:\\'
+    out = 'G:\sentinel'
+    s22rgb(img, out)
